==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/FunnelSliceEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelSliceEventArgsDescription } from "./FunnelSliceEventArgsDescription";
/**
 * @hidden
 */
export let FunnelSliceEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunnelSliceEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FunnelSliceEventArgsDescriptionMetadata.a == null) {
                FunnelSliceEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunnelSliceEventArgsDescriptionMetadata.c(FunnelSliceEventArgsDescriptionMetadata.a);
            }
            if (a.k(FunnelSliceEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(FunnelSliceEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("Bounds", "Rect");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            FunnelSliceEventArgsDescriptionMetadata.b(a);
            a.ad("FunnelSliceEventArgs", () => new FunnelSliceEventArgsDescription());
            a.ac("FunnelSliceEventArgs", FunnelSliceEventArgsDescriptionMetadata.a);
        }
    }
    FunnelSliceEventArgsDescriptionMetadata.$t = markType(FunnelSliceEventArgsDescriptionMetadata, 'FunnelSliceEventArgsDescriptionMetadata');
    FunnelSliceEventArgsDescriptionMetadata.a = null;
    return FunnelSliceEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/FunnelSliceEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelSliceEventArgsDescription } from "./FunnelSliceEventArgsDescription";
/**
 * @hidden
 */
export let FunnelSliceEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunnelSliceEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FunnelSliceEventArgsDescriptionMetadata.a == null) {
                FunnelSliceEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunnelSliceEventArgsDescriptionMetadata.c(FunnelSliceEventArgsDescriptionMetadata.a);
            }
            if (a.k(FunnelSliceEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(FunnelSliceEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("Bounds", "Rect");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Position", "Point");
        }
        static d(a) {
            FunnelSliceEventArgsDescriptionMetadata.b(a);
            a.ae("FunnelSliceEventArgs", () => new FunnelSliceEventArgsDescription());
            a.ad("FunnelSliceEventArgs", FunnelSliceEventArgsDescriptionMetadata.a);
        }
    }
    FunnelSliceEventArgsDescriptionMetadata.$t = markType(FunnelSliceEventArgsDescriptionMetadata, 'FunnelSliceEventArgsDescriptionMetadata');
    FunnelSliceEventArgsDescriptionMetadata.a = null;
    return FunnelSliceEventArgsDescriptionMetadata;
})();
